import {
  pie,
  select,
  selectAll,
  scaleLinear,
  axisBottom,
  axisLeft,
  range,
  max,
  schemeSet3,
  easeElasticOut,
} from 'd3';

const w =
  d3.min([window.innerWidth, window.innerHeight]) - 40;
const h = w;

const dataset = [5, 10, 20, 45, 6, 25];

const pie_chart = pie().sort(null).padAngle(0.008);

const outerRadius = w / 2;
const innerRadius = w / 3;

const arc = d3
  .arc()
  .innerRadius(innerRadius)
  .outerRadius(outerRadius);

const svg = select('body')
  .append('svg')
  .attr('width', w)
  .attr('height', h);

const arcs = svg
  .selectAll('g.arc')
  .data(pie_chart(dataset))
  .join('g')
  .attr('class', 'arc')
  .attr(
    'transform',
    `translate(${outerRadius}, ${outerRadius})`
  );

const color = d3.scaleOrdinal(d3.schemeCategory10);

arcs
  .append('path')
  .attr('fill', (d, i) => color(i))
  .attr('d', arc);

arcs
  .append('text')
  .attr('transform', (d) => `translate(${arc.centroid(d)})`)
  .text((d) => d.value)
  .style('fill', 'white')
  .style('font-size', '16px')
  .style('font-family', 'mono');
